////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////
// Adapted from main BSA .do files 2015/3/17
////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////

// The datasets
global s1983 "${BSAdir}\BSA 1983 (SN1935)\stata8\bsa83.dta"
global s1984 "${BSAdir}\BSA 1984 (SN2035)\stata8\bsa84.dta"
global s1985 "${BSAdir}\BSA 1985 (SN2096)\stata8\bsa85.dta"
global s1986 "${BSAdir}\BSA 1986 (SN2315)\stata8\2315.dta"
global s1987 "${BSAdir}\BSA 1987 (SN2567)\stata8\bsa87.dta"
global s1989 "${BSAdir}\BSA 1989 (SN2723)\stata8\2723.dta"
global s1990 "${BSAdir}\BSA 1990 (SN2840)\stata6\bsa90.dta"
global s1991 "${BSAdir}\BSA 1991 (SN2952)\stata8\f952.dta"
global s1993 "${BSAdir}\BSA 1993 (SN3439)\stata8\bsa93.dta"
global s1994 "${BSAdir}\BSA 1994 (SN3572)\stata8\bsa94.dta"
global s1995 "${BSAdir}\BSA 1995 (SN3764)\stata8\bsa95.dta"
global s1996 "${BSAdir}\BSA 1996 (SN3921)\stata8\g921au.dta"			// 1996 has two files, one of which has only 42 cases which I've ignored - these 42 cases are not duplicates (juding by their serial no), but documentation doesn't explain them...
global s1997 "${BSAdir}\BSA 1997 (SN4072)\stata6\bsa97a.dta"
global s1998 "${BSAdir}\BSA 1998 (SN4131)\stata8\bsa98a.dta"
global s1999 "${BSAdir}\BSA 1999 (SN4318)\stata8\bsa99a.dta"
global s2000 "${BSAdir}\BSA 2000 (SN4486)\stata8\bsa00.dta"
global s2001 "${BSAdir}\BSA 2001 (SN4615)\stata6\bsa01merged.dta"		// Edited from downloaded version - see 1_bsaTS_datafile.do
global s2002 "${BSAdir}\BSA 2002 (SN4838)\stata6\bsa02.dta"
global s2003 "${BSAdir}\BSA 2003 (SN5235)\stata6\bsa03.dta"
global s2004 "${BSAdir}\BSA 2004 (SN5329)\stata8\bsa04.dta"
global s2005 "${BSAdir}\BSA 2005 (SN5618)\stata8\bsa05.dta"
global s2006 "${BSAdir}\BSA 2006 (SN5823)\stata8\bsa06.dta"
global s2007 "${BSAdir}\BSA 2007 (SN6240)\stata8\bsa07.dta"
global s2008 "${BSAdir}\BSA 2008 (SN6390)\stata8\bsa08.dta"
global s2009 "${BSAdir}\BSA 2009 (SN6695)\stata8\bsa09.dta"
global s2010 "${BSAdir}\BSA 2010 (SN6969)\stata9\bsa10lowercase.dta"	// Edited from downloaded version - see 1_bsaTS_datafile.do
global s2011 "${BSAdir}\BSA 2011 (SN7237)\stata11\bsa11lowercase.dta"	// As in 2010
global s2012 "${BSAdir}\BSA 2012 via NatCen\bsa12.dta"					// Direct from NatCen, not via Data Archive - but since available from http://discover.ukdataservice.ac.uk/catalogue/?sn=7476&type=Data%20catalogue
global s2013 "${BSAdir}\BSA 2013 via NatCen\bsa13v3.dta"				// Direct from NatCen, not via Data Archive - but since available from http://discover.ukdataservice.ac.uk/catalogue/?sn=7500&type=Data%20catalogue


///////////////////////////////////////////
///////////////////////////////////////////
// DATA PREPARATION
///////////////////////////////////////////
///////////////////////////////////////////

/* ONE OFF PREPARATIONS
	* 2012 and 2013 are currently from NatCen ahead of public release, so needs minor additional work - also an issue over var name in 2013
	usespss using "${BSAdir}\BSA 2013 via NatCen\bsa13v3.sav", clear
		renvars _all, lower
		save "${BSAdir}\BSA 2013 via NatCen\bsa13v3.dta", replace
	usespss using "${BSAdir}\BSA 2012 via NatCen\bsa12.sav", clear
		renvars _all, lower
		save "${BSAdir}\BSA 2012 via NatCen\bsa12.dta", replace	

	* 2010 onwards need varnames putting into lowercase 
		* PREVIOUSLY DONE USING A LOOP OVER ALL VARS, WITH ren - BUT 2014 CHANGED TO RENVARS
	use "${BSAdir}\BSA 2011 (SN7237)\stata11\bsa11.dta", replace
		renvars _all, lower
		save "${BSAdir}\BSA 2011 (SN7237)\stata11\bsa11lowercase.dta", replace
	use "${BSAdir}\BSA 2010 (SN6969)\stata9\bsa10.dta", replace
		renvars _all, lower
		save "${BSAdir}\BSA 2010 (SN6969)\stata9\bsa10lowercase.dta", replace

	* 2001 has two files that need merging (one containing SOC) - ONLY NEEDS DOING ONCE
	cd "E:\Work reference\Datasets misc\BSA\BSA 2001 (SN4615)\stata6"
	use bsa01soc
		sort serial
		save, replace
	use bsa01
		sort serial
	merge serial using bsa01soc
		drop _merge
	save bsa01merged, replace
END ONE-OFF PREPS*/


************************************************
* Getting a file with all the key variables in it
* (This is for all BSA analyses, not just this)
************************************************
local BSAvars "rage rsex hedqual cchqual hhincome hhincd hhincq cchinc srinc hincdiff hincdif4 reconact seconact qprived rclass rclassgp rnseg rghclass " 
local BSAvars "`BSAvars' married marstat srhealth wtfactor selfcomp serial sintdate qdate p2rel p2age p3rel p3age p4rel p4age p5rel p5age p6rel p6age "
local BSAvars "`BSAvars' p7rel p7age p8rel p8age p9rel p9age p10rel p10age p11rel p11age p12rel p12age"	// For deriving number of kids under a certain age in the hhld
local BSAvars "`BSAvars' gor gor2 stregion reconpos wkjbhrsi"
// Own benefit claims
local BSAvars "`BSAvars' anybn2 anybn3 anybnew benefpip benefuc beneft14 benefcb beneft1 beneft2 benefct beneft15 benftn11 benefata benefdla benefica beneft8 benftn13"
local BSAvars "`BSAvars' benftn8 benefhb beneft12 benftn5 benefinc benefind benefsev beneft7 beneft9 benftn14 benftn6 benftn7 benefop beneft3 benftn3"
local BSAvars "`BSAvars' benefoth beneft13 benftn12 benefoap benefpc beneft5 beneft6 benefwar benefwid benftn10 benefis benefis2 beneft11 benftn2"
local BSAvars "`BSAvars' benefcct benefctc benefdwa beneffc beneft4 benftn4 benftn9 beneft10 benefub benftn1" 
local BSAvars "`BSAvars' benub benis bendb bencab bentc benhb bencot benpc bennone benfub benfis benfdb benfcab benftc benfhb benfcot benfpc benfnone"
local BSAvars "`BSAvars' maininc5 maininc4 maininc2 maininc3 maininc srsoccl srsoccl1 srsoccl2 srsoccle"
// Attitudinal questions
local BSAvars "`BSAvars' taxspend spend1 spend2 socspnd1 socspnd2 socspnd3 socspnd4 socspnd5 socspnd6 morewelf damlives"
local BSAvars "`BSAvars' r12num provhouse provjob provdisb shamhelp shamfam wksmstdy wksmcas wksmsick wksmself wksmoutw wksminou wksmhome wksmnone wksmeduc"
local BSAvars "`BSAvars' ptyalleg partyid1 partyid2 libauth leftrigh readpap whpaper webnews wnwsite1 wnwsite2 interpap whintpap tvnews wealth incomgap redistrb richlaw indust4"
local BSAvars "`BSAvars' sochelp unempjob falsedb falseub dolefidl falseclm bencheat disab500 ben500 cohab500 govben falsconf cheatpor benidcrd informbn"
local BSAvars "`BSAvars' impben1 impben2 welfstig failclm dole welfhelp welffeet muchpov pastpov futurpov poverty1 poverty2 poverty3" 
local BSAvars "`BSAvars' resgunp respday respbrit ruhappy3 wksmstdy wksmcas wksmsick wksmself wksmoutw wksminou wksmhome wksmnone wksmeduc"
local BSAvars "`BSAvars' whyneed natprid4 proudwlf nocontct nomoney noslfcon lsrespct famtensn lsjbexpr toomchtm dkunemp ubbase"
local BSAvars "`BSAvars' spenmost spennext spenlast socbmost socbnext socblast taxvat propr100 prpen100 prsch100 vicri100 hipay100 chpov100 blasi100 car100 harmtra1 harmtra2 "
local BSAvars "`BSAvars' ub1poor ub1on45 ub1on47 ub1on52 ub1on72 ubcpoor ubcon88 mumpoor mumon77 mumon78 mumon95 mumon130 carpoor caron146 pen1poor pen1on82 penon105 penon119 pencpoor penco171"
local BSAvars "`BSAvars' penspoor poorspno pensrent penspoo1 penspoo2 poorspn1 poorspn2 poor62 ubpoor2 poorub40 ub40rent ubpoor1 poorub41 poorub42 ubpoor poor50" // Added 21/7/2015
local BSAvars "`BSAvars' ahead1 ahead2 ahead3 ahead4 ahead5 ahead6 ahead7 ahead8 ahead9 ahead10 ahead11 ahead12 ahead17 incopp1 incopp2 whrchpar whyneed whyrich incprior equalopp equalop2 rjobfjob" 	// For the TUC mobilities work
local BSAvars "`BSAvars' socscale socscl10 srsoccl1 srsoccl2 srsoccl topupchn topupnch topuplpa lowwage mwagpoor"
* REMOVED: For blog post April 2013 on attitudes to immigrants claiming benefits
// Belief questions from 2001
local BSAvars "`BSAvars' spenmost spennext spenlast socbmost socbnext socblast propr100 prpen100 vicri100 prsch100 hipay100 chpov100 blasi100 car100"
cd "$dir"
*foreach year in 1983 1984 1985 1986 1987 1989 1990 1991 1993 1994 1995 1996 1997 1998 1999 2000 2001 2002 2003 2004 2005 2006 2007 2008 2009 2010 2011 2012 2013	{
* To speed this up - as we only use certain years for this analyses
foreach year in 1986 1989 1991 1993 1994 1995 1996 1998 1999 2000 2001 2004 2005 2007 2008 2013 {
	use "${s`year'}", replace
	local keepvars ""
	foreach var in `BSAvars' {
		capture confirm variable `var'
		if _rc==0		local keepvars "`keepvars' `var'"
		/**/			}
	dis in yellow "Year is `year' , vars to keep are `keepvars'"
	keep `keepvars'
	gen svyyear = `year'
	if `year' == 2007	ren sintdate sintdateNUM
	save working`year'.dta, replace
	/**/																							}
use working2013.dta, replace
*foreach year in 1983 1984 1985 1986 1987 1989 1990 1991 1993 1994 1995 1996 1997 1998 1999 2000 2001 2002 2003 2004 2005 2006 2007 2008	2009 2010 2011 2012 {
* To speed this up - as we only use certain years for this analyses
foreach year in 1986 1989 1991 1993 1994 1995 1996 1998 1999 2000 2001 2004 2005 2007 2008 {
	quietly append using  working`year'.dta
	erase working`year'.dta
	/**/															}
numlabel _all, mask(#_) add

* Finally
save "${workingdir}\\${filename}_bsa", replace



///////////////////////////////////////////
///////////////////////////////////////////
// DATA CLEANING
///////////////////////////////////////////
///////////////////////////////////////////




////////////////////////////////////////////////////
// Politics
////////////////////////////////////////////////////

label var libauth 	"libertarian-authoritarian scale (high=authoritarian)"
recode partyid1 (1=1 "1_Con")(2=2 "2_Lab")(3=3 "3_LD")(11=4 "4_UKIP/Veritas")(6/8 11/13 95=5 "5_Other party")(9 10 97 98 99 -99=6 "6_Other answer")(-1=.n), gen(_partyid)		// -99 only used in 1993, but seems to refer to people who weren't asked the q because they didn't support any party

/* In previous versions I have used the following code - but changed for this one, esp. as UKIP have risen so much
// Main political vars
recode partyid2 (-99 -1=.)
recode partyid2 (1=1 "1_tory")(2=2 "2_labour")(3=3 "3_LD")(4 6=4 "4_Other")(5=5 "5_None")(8=8 "8_DK/R/conflicted"), gen(partyidR)	// Aside from 1983 (which is different), PARTYID1==97 is people who gave other answers that couldn't be considered 'no party' - so conflicted answers probably.  Only small numbers anyway.
* Dummies
recode partyid2 (1=1 "1_tory") 	(2/8=0 "0_other")	, gen(partycon)
recode partyid2 (2=1 "1_labour")(1 3/8=0 "0_other")	, gen(partylab)
recode partyid2 (2=1 "1_labour")(1 3/8=0 "0_other")	, gen(labour)		// Something I generated for a previous version that I've left in for reference
recode partyid2 (1=1 "1_Con")(2=2 "2_Lab")(3=3 "3_LD")(4/8=8 "8_none/oth/DK/ref"), gen(party4)
// More detailed version
*recode ptyalleg (-99 98=.) (1/3 7/14=1) (4=4 "4_labour partisan") (5=5 "5_labour sympathiser") (6=6 "6_labour residual identifier"), gen(lballeg)	
*/



////////////////////////////////////////////////////
// Newspaper readership 
// (changed from BSA14 version, itself added from BSA07 version 13/6/2014)
////////////////////////////////////////////////////

* Making it consistent
recode whpaper (6=95) if svyyear<=1995
recode whpaper (12=94)(13=95)(14=96) if svyyear==1986
recode whpaper (11=94)(12=95)(13=96) if svyyear<=1985
* Recoding into the form I want
recode whpaper (-1=0)(4 6=12)(8 12 94/96=99)(98=.d)(99=.r)(-9=.), gen(_paper)
	replace _paper = 99 if readpap==1 & missing(_paper )
	replace _paper = 0  if readpap==2 & missing(_paper )
	label copy WhPaper _paper
		label define _paper 0 "0_no paper" 12 "12_Daily Record or Daily Star" 99 "99_all other, inc multiple papers", modify
		label values _paper _paper 
		
			
	
////////////////////////////////////////////////////
// Benefit claiming vars 
*  2015 version for this project - based on 2014 version, which in turn was slightly adapated from 2007 syntax
////////////////////////////////////////////////////
global outofwrkbens	"benefica benefinc benefind benefis benefis2 benefop benefsev benefub"
global lowincbens	"benefct benefdwa benefhb benefpc benefcct benefctc benefuc beneffc "
global otherbens	"benefata benefdla benefpip benefwar "						// Not benefoap benefcb benefwid benefoth 
global disbens		"benefata benefinc benefdla benefsev benefpip benefwar"		// As a subset of the above, not mutually exclusive
local allbenvars "${outofwrkbens} ${lowincbens} ${otherbens}"
foreach var in `allbenvars'  	{
	recode `var' (-9=.r)(-1=0)(8=.d)(9=.r)
	replace `var' = 0 if missing(`var') & anybn3==2 & (svyyear==2012 | svyyear==2013)		// Slightly different coding in these years for some reason
	/**/					}
unab bens93_95 : benftn* 		// Different but comparable version of the questions 1993-1995
foreach var in `bens93_95'  	{
	recode `var' (-9=.r)(-1=0)(1/7=1)(8=.d)(9=.r)		// Strangely the 'has received' numbers change in weird ways between vars and years
	/**/						}

// All benefits
egen _anyben = anymatch(${outofwrkbens} ${lowincbens} ${otherbens})	, values(1) 
	replace _anyben = . if missing(benefoap)
	label var _anyben "Benefit claimant: any benefit (inc. child benefit & TCs)"
	// Haven't incorporated 1993-1995 versions as the ben list is different - esp. non-inclusion of Child Benefit
	proportion _anyben [pweight=wtfactor], over(svyyear)
// Disability benefits - excludes War (Disablement) Pension as will mainly be widows
egen _disben 	= anymatch(${disbens})									, values(1) 
	replace _disben = . if missing(benefoap)
	replace _disben = 1 if (benefis2==1 | benefis==1) & reconact==8		// What I'm assuming are credits-only claimants
	label var _disben "Benefit claimant: disability"
	// Incorporating 1993-1995 versions
	egen D_disben = anymatch(benftn6 benftn7 benftn8 benftn13 benftn14), values(1)
	replace _disben = D_disben if ~missing(benftn1)
	proportion _disben [pweight=wtfactor], over(svyyear)
// Income-related benefits (inc out of work benefits)
egen _irben = anymatch(${outofwrkbens} ${lowincbens})					, values(1) 
	replace _irben = . if missing(benefoap)
	label var _irben "Benefit claimant: income-related/out-of-work"
	// Incorporating 1993-1995 versions
	egen D_irben = anymatch(benftn1 benftn2 benftn3 benftn6 benftn7 benftn14), values(1 2 3 4 5 6 7 8 9 11 13)
	replace _irben = D_irben if ~missing(benftn1)
	proportion _irben [pweight=wtfactor], over(svyyear)
// Out-of-work benefits
egen _outofwrkben = anymatch(${outofwrkbens})								, values(1) 
	replace _outofwrkben = . if missing(benefoap)
	label var _outofwrkben "Benefit claimant: out-of-work"
	// Incorporating 1993-1995 versions
	egen D_outofwrkben = anymatch(benftn1 benftn2 benftn3 benftn6 benftn7 benftn14), values(1 2 3 7 14)
	replace _outofwrkben = D_outofwrkben if ~missing(benftn1)
	proportion _outofwrkben [pweight=wtfactor], over(svyyear)
drop D*
order _anyben-_outofwrkben, after(benefoth)


* From main source of income
recode maininc  (4/8=1  "1_state bens/TCs")(1=2 "2_earnings")(2    9/12=3 "3_private/other")(3=4 "4_state pension")(98=.d)(99=.r), gen(maininc1R)
recode maininc3 (5/8=1  "1_state bens/TCs")(1=2 "2_earnings")(2 3  9/12=3 "3_private/other")(4=4 "4_state pension")(98=.d)(99=.r), gen(maininc3R)
recode maininc4 (5/9=1  "1_state bens/TCs")(1=2 "2_earnings")(2 3 10/13=3 "3_private/other")(4=4 "4_state pension")(98=.d)(99=.r) if svyyear<2013 , gen(maininc4R)
recode maininc5 (5/11=1 "1_state bens/TCs")(1=2 "2_earnings")(2 3 12/15=3 "3_private/other")(4=4 "4_state pension")(98=.d)(99=.r) if svyyear==2013, gen(maininc5R)	// I've renamed this variable as the response categories change (see spreadsheet)
clonevar mainben = maininc1R
forvalues i = 3/5	{
	replace mainben	= maininc`i'R if ~missing(maininc`i'R)
	/**/			}
label var mainben "Main source of income 1995-2013, state bens/TCs==1"
recode mainben (1=1 "1_state bens/TCs")(2/4=0 "0_other"), gen(mainbenB)
label var mainbenB "Main source of income 1995-2013, binarised"


* 1995 data mistakenly has beneft13, a duplicate of benftn12
replace beneft13=. if svyyear==1995

	


////////////////////////////////////////////////////
// Sociodemographics
////////////////////////////////////////////////////

* Education
recode hedqual (1=1 "1_degree") (2/3=2 "2_>A-level") (4/6=3 "3_<A-level") (7=4 "4_no quals") (8=.d), gen(edgrp)
label var edgrp "Education (3-group)"

* Social class (NatCen recommended versions when writing BSA13 chapter)
recode rclassgp (-1=.n)(8=.u)
	// For 2001, when they have RCLASS but not the summarised form RCLASSGP
	recode rclass (-1=.n)(1 2=1)(3=2)(4=3)(5=4)(6 7=5)(8=.u), gen(Drclass)
	replace rclassgp = Drclass if svyyear==2001
	drop Drclass
recode rnseg (1/2 4/8=1)(9=2)(3 15/17=3)(11/12=4)(10 13 14 18=5)(else=.) , gen(Drnseg)
recode rghclass (1/2=1)(3/4=2)(5/7=3)(8=4)(9/11=5)(else=.), gen(Drghclass)
tab Drnseg Drghclass if svyyear==2001
// Single var
gen rclasscons 		= Drnseg 	if ~missing(Drnseg)
replace rclasscons	= Drghclass if ~missing(Drghclass)
label define rclasscons 1 "1_Salariat (Higher + Lower)" 2 "2_Clerical (Junior non-manual)" 3 "3_Petty Bourgeois" 4 "4_Foremen/Technicians" 5 "5_Working class", replace
label values rclasscons rclasscons
label var rclasscons "Occupational class (semi-consistent version from NatCen)"
drop Drnseg Drghclass

* OWN working status
mvdecode reconact, mv(99=.r)
// Working hours
recode wkjbhrsi (-3 -1=.n)(96 98=.d)(99=.r) 	// 96 is 'varies too much to say', 95=95+, 'a job' is 10hrs+

/* HOUSEHOLD working status
mvdecode seconact, mv(0 -1=.)
gen hhldwrk = .
	replace hhldwrk	= 1 if (reconact==3 | reconact==4) 					& (seconact==3 | seconact==4)
	replace hhldwrk = 2 if (reconact==3 | reconact==4) 					&  missing(seconact)
	replace hhldwrk = 3 if (reconact==2 | (reconact>=5 & reconact<. )) 	& (seconact==3 | seconact==4)
	replace hhldwrk = 4 if (reconact==3 | seconact==4) 					& (seconact==2 | (seconact>=5 & seconact<98))
	replace hhldwrk = 5 if (reconact==2 | (reconact>=5 & reconact<98)) 	& (seconact==2 | (seconact>=5 & seconact<98))
replace hhldwrk=. if svyyear==1983	// No data on SECONACT
label define hhldwrk 1 "1_both working" 2 "2_single hhld wrking" 3 "3_r wrking, s not" 4 "4_r not wrking, s works" 5 "5_neither wrking", replace
label values hhldwrk hhldwrk
label var hhldwrk "Working status of household, exc. those in f/t education"
tab svyyear hhldwrk, row nof
*/

* Region
recode gor (1=1)(2 3=2)(4=3)(5=4)(6=5)(7=6)(8=7)(9=10)(10=13)(11=11)(12=12), gen(_region)
	replace _region = gor2 if missing(_region) & gor2~=9 & gor2~=8
	replace _region = 13 if gor2==9 | gor2==8
label var _region "Govt Standard Region, comparable from 2000"
	capture label copy GOR2 _region
	label define _region 13 "13_London (Inner+Outer), comparable to GOR pre-2003", modify
	label values _region _region


////////////////////////////////////////////////////
// 2001 beliefs questions
////////////////////////////////////////////////////

recode *100 (-2=.n)(998=.d)(999=.r)
recode spenmost spennext spenlast (98=.d)(99=.r)
recode socbmost socbnext socblast (8=.d)(9=.r)
renvars car100 chpov100 hipay100 propr100 prpen100 prsch100 vicri100 blasi100, prefix(oth_)		// So that the non-benefit belief questions are obvious


////////////////////////////////////////////////////
// 2007 perceived fraud questions
////////////////////////////////////////////////////

ren falsedb falseIB
ren falseub	falseJSA
mvdecode falseIB falseJSA, mv(-2=.s \ 998=.d \ 999=.r)
label define falseub .s ".s_Skip (version A)", modify
label define falsedb .s ".s_Skip (version A)", modify


////////////////////////////////////////////////////
// Benefit beliefs re value of payment
////////////////////////////////////////////////////
ren penon*		pen1on*
ren penco171	pencon171
recode pensrent	(1=4)(2=3)(3=2)(4=1)(8=.d)(9=.r), gen(pencon103)
	drop pensrent
	label values pencon103 UB1Poor
recode ub40rent (1=4)(2=3)(3=2)(4=1)(8=.d)(9=.r), gen(ubcon79)
	drop ub40rent
	label values ubcon79 UB1Poor
* Consistent versions pre-1998
replace penspoor = penspoo1 if ~missing(penspoo1)
	replace penspoor = penspoo2 if ~missing(penspoo2)
	recode penspoor (-1=.n)(1=4)(2=3)(3=2)(4=1)(8=.d)(9=.r), gen(penspoorR)
	replace pencpoor = penspoorR if penspoorR~=.
	drop penspoor penspoo1 penspoo2 penspoorR
replace ubpoor = ubpoor1 if ~missing(ubpoor1)
	replace ubpoor = ubpoor2 if ~missing(ubpoor2)
	recode ubpoor (-1=.n)(1=4)(2=3)(3=2)(4=1)(8=.d)(9=.r), gen(ubpoorR)
	replace ubcpoor= ubpoorR if ubpoorR~=.
	drop ubpoor ubpoor1 ubpoor2 ubpoorR 
* Getting a more sensible consistent naming practice than BSA usually do...
gen ub1onX = .
	label var ub1onX "Whether think 25yo unemp women on £X is poor (dv)"
	foreach value in 45 47 52 72 	{
		replace ub1onX = ub1on`value' if missing(ub1onX) & ~missing(ub1on`value')
		drop ub1on`value'
		/**/						}
gen mumonX = .
	label var mumonX "Whether think single mum on £X is poor (dv)"
	foreach value in 77 78 95 130 	{
		replace mumonX = mumon`value' if missing(mumonX) & ~missing(mumon`value')
		drop mumon`value'
		/**/						}
gen pen1onX = .
	label var pen1onX "Whether think single pensioner on £X is poor (dv)"
	foreach value in 82 105 119 	{
		replace pen1onX = pen1on`value' if missing(pen1onX) & ~missing(pen1on`value')
		drop pen1on`value'
		/**/						}
gen penconX = .
	label var penconX "Whether think pensioner couple on £X is poor (dv)"
	foreach value in 103 171		{
		replace penconX = pencon`value' if missing(penconX) & ~missing(pencon`value')
		drop pencon`value'
		/**/						}
gen ubconX = .
	label var ubconX "Whether think unemployed couple on £X is poor (dv)"
	foreach value in 79 88 		{
		replace ubconX = ubcon`value' if missing(ubconX) & ~missing(ubcon`value')
		drop ubcon`value'
		/**/						}
* The earlier version that does NOT say 'after rent', which gives really different results in 1998
replace poorspno = poorspn1 if ~missing(poorspn1)
	replace poorspno = poorspn2 if ~missing(poorspn2)
	replace poorspno = poor62   if ~missing(poor62)
	recode poorspno (1=4)(2=3)(3=2)(4=1)(8=8)(9=9)(-1=.n), gen(penconX_incrent)
	drop poorspno poorspn1 poorspn2 poor62
replace poorub40 = poorub41 if ~missing(poorub41)
	replace poorub40 = poorub42 if ~missing(poorub42)
	replace poorub40  = poor50   if ~missing(poor50)
	recode poorub40 (1=4)(2=3)(3=2)(4=1)(8=8)(9=9)(-1=.n), gen(ubconX_incrent)
	drop poorub40 poorub41 poorub42 poor50 
* Tidying all these
label values *onX* UB1Poor

// Missing values
unab benlevelvars: ub1* ubc* mum* car* pen1* penc*
* For BSA-consistent outputs - N seemed not to be used for anything else (no other logic!)
foreach var in `benlevelvars' 	{
	recode `var' (-2=.n)(8/9=9 "9_dk or refusal")(1/2=2 "2_(more than) enough to live on")(3/4=1 "1_hard up/really poor"), gen(`var'N)
	recode `var' (-2=.n)(8/9=9 "9_dk or refusal")(1=4 "4_more than enough")(2=3 "3_enough to live on")(3=2 "2_hard up")(4=1 "1_hard up/really poor"), gen(`var'N2)
	/**/						}
* Other missing values
mvdecode `benlevelvars', mv(-2=.n \ 8=.d \ 9=.r)
gen serialodd =  mod(serial,2)		// This gives the remainder from dividing the serial number by 2. For the qs below, different versions were asked to odd and seven serial numbers (with n<10 mis-routing in each case). The .n is used below for setting the XG variables appropriately
replace ubconX_incrent = .n if serialodd==0 & svyyear==1998
replace ubconX 		   = .n if serialodd==1 & svyyear==1998
drop serialodd

		
* Looking at the difference between the two versions to see if people overestimate or underestimate claims
capture drop *_diff *G
foreach pair in "ub1poor ub1onX" "ubcpoor ubconX" "ubcpoor ubconX_incrent" "mumpoor mumonX" "carpoor caron146" "pen1poor pen1onX" "pencpoor penconX" "pencpoor penconX_incrent" 	{
	local var1 = word(`"`pair'"',1)
	local var2 = word(`"`pair'"',2)
	local vign = subinstr(`"`var2'"',"on","_",.)
	dis "`vign'"
	gen `vign'_diff = (`var1'- `var2') if ~missing(`var2', `var2')
	recode `vign'_diff (1/3=1 "1_understimated ben") (0=2 "2_no change") (-3/-1=3 "3_overestimated ben"), gen(`vign'G)
	replace `vign'G = .d if (`var1'==.d | `var'2==.d) 
	replace `vign'G = .r if (`var1'==.r | `var'2==.r) 
	replace `vign'G = . if ("`var2'"=="ubconX" | "`var2'"=="penconX") 					& (svyyear<1998 | (svyyear==1998 & ubconX==.n))
	replace `vign'G = . if ("`var2'"=="ubconX_incrent" | "`var2'"=="penconX_incrent") 	& (svyyear>1998 | (svyyear==1998 & ubconX_incrent==.n))
	/**/																																									}
drop *_diff
* Labelling the DVs
label var ub1_XG  	"Implicit ben knowledge: 25yo unemp woman (various levels)"
label var ubc_XG    "Implicit ben knowledge: unemp couple (various levels)"
label var mum_XG   	"Implicit ben knowledge: unemp single mum+young child (various levels)"
label var car_146G  "Implicit ben knowledge: woman caring for husband (£146pw, 2004)"
label var pen1_XG  	"Implicit ben knowledge: single pensioner (various levels)"
label var penc_XG   "Implicit ben knowledge: pensioner couple (various levels)"
label var ubc_X_increntG    "Implicit ben knowledge: unemp couple (rent not mentioned, various levels)"
label var penc_X_increntG   "Implicit ben knowledge: pensioner couple (rent not mentioned, various levels)"




////////////////////////////////////////////////////
// Main welfare attitudes
////////////////////////////////////////////////////

// Misc cleaning
* So all coded in same direction
recode welfstig (1=5 "5_disagree strongly") (2=4 "4_just disagree") (4=2 "2_just agree") (5=1 "1_agree strongly"), gen(welfstigR)
* Other cleaning
recode whyneed (6 7=5)			// These are spontaneous reports from early years
replace falseclm = 8 if falseclm==5 & svyyear==1983 	// early don't know coding
replace failclm  = 8 if failclm==5  & svyyear==1983 	// early don't know coding

// Missing data 
unab benattvars: welfstigR damlives welfhelp welffeet sochelp dolefidl unempjob proudwlf lowwage
* BSA-consistent version
foreach var in `benattvars' 	{
	recode `var' (-2 -1 0=.n)(1/2=1 "1_agree(strongly)")(3/5=2 "2_neither/disagree(strongly)")(8/9=9 "9_dk or refusal"), gen(`var'N)
	/**/						}	
foreach var in falseclm failclm	{
	recode `var' (-2 0=.n)(8/9=9 "9_dk or refusal")(1/2=1 "1_agree(strongly)")(3/4=2 "2_neither/disagree(strongly)"), gen(`var'N)
	/**/						}
foreach var in topupchn topupnch topuplpa	{
	recode `var' (-2 -1=.)(1=1 "1_Govt should top-up wages")(2=2 "2_Shld not top up")(8 9=9), gen(`var'N)
	/**/									}
* Usual approach of putting non-responses as system-missing
mvdecode `benattvars' falseclm natprid4 ubbase incomgap, mv(-7=.t \ -2 =.s \ -1=.s \ 0=.s \ 8=.d \ 9=.r) // 0 only appears for WELFHELP 1985, assuming this is about routing (like -1 or -2)
// Poverty variables - for BSA, followed by usual approach
recode muchpov (-2=.n)(1=1 "1_very little real poverty")(2=2 "2_quite a lot")(8/9=9 "9_dk or refusal"), gen(muchpovN)
recode pastpov (-2=.n)(1=1 "1_increasing")(2=2 "2_same")(3=3 "3_decreasing")(8/9=9 "9_dk or refusal"), gen(pastpovN)
forvalues i = 1/3	{
	recode poverty`i' (-2=.n)(1=1 "1_was in poverty")(2=2 "2_not")(8/9=9 "9_dk or refusal"), gen(poverty`i'N)
	/**/			}
recode muchpov pastpov futurpov poverty? (-7 -2=.)(8=.d)(9=.r)		// For usual approach
// Other vars requiring unique approach
mvdecode govben, mv(-7=.t \ -2 =.s \ -1=.s \ 0=.s \ 9=.r)		// 8 is a substantive answer ('can't choose')
recode failclm (-2=.s) (1=1 "1_agree strongly") (2=2 "2_agree") (3=4 "4_disagree") (4=5 "5_disagree strongly") (5 8=3 "3_dk (spontaneous?)") (9=.r), gen(failclmR)
recode impben1 impben2 (-2=.s) (-1=8) (98=.d)
////////////////////////////////////////////////////
// Binarised versions
* Binary 'agree' versions of multicoded questions
foreach var in morewelf	damlives welfstig falseclm unempjob sochelp dolefidl failclmR welfhelp welffeet proudwlf {
	recode `var' (1/2=1 "1_(strongly)agree")(3/5=2 "2_not agree"), gen(`var'B)
	/**/				}
* Binary variables where not just an agree scale
recode natprid4 (1/2=1 "1_(very/somewhat)proud") (3/4=0 "0_not proud"), gen(natprid4B)
gen whyneedB = (whyneed==2) if ~missing(whyneed)
	label var whyneedB "People in need due to laziness/lack of will (from WHYNEED)"
////////////////////////////////////////////////////
// Renaming for the qs used in Leuven book chapter 2016
ren (sochelp unempjob falseclm) D=

	
/*
////////////////////////////////////////////////////
// Welfare spending attitudes
////////////////////////////////////////////////////

* Priorities for extra spending per se
forvalues i = 1/2	{
	recode spend`i' (11 98 99=99)(-2/0 12=.), gen(spend`i'N)		// 12 is prob a miscoding; it's just there in 1983.  But -1 in certain years is there for DKs at spend1, or people who said 'none of these' at spend1, which I want to treat differently
	* Labelling
	local varlabel : value label spend`i'
	label copy `varlabel' spend`i'N, replace
	label define spend`i'N 99 "99_none or dk or refusal", modify
	label values spend`i'N spend`i'N
	* My usual version, rather than BSA consistent tables
	recode spend`i' (98=.d)(99=.r)(-2/0 12=.)					// 12 is prob a miscoding; it's just there in 1983.  But -1 in certain years is there for DKs at spend1, or people who said 'none of these' at spend1, which I want to treat differently
	/**/						}
replace spend2 = 11 if spend1 == 11 & missing(spend2)	
gen spend1soc 	= (spend1==8)  if ~missing(spend1)
gen spend1socN  = (spend1N==8) if ~missing(spend1N)
gen spend12soc  = (spend1==8  | spend2==8)  if ~missing(spend1)  
gen spend12socN = (spend1N==8 | spend2N==8) if ~missing(spend1N)  

* Main socspend vars
mvdecode socspnd?, mv(-2=.n)
recode socspnd1 (1 2=1 "1_spend more")(3=2 "2_spend same")(4/5=3 "3_spend less")(8/9=9 "9_dk or refusal"), gen(socunempN)
recode socspnd2 (1 2=1 "1_spend more")(3=2 "2_spend same")(4/5=3 "3_spend less")(8/9=9 "9_dk or refusal"), gen(socdisN)
recode socspnd3 (1 2=1 "1_spend more")(3=2 "2_spend same")(4/5=3 "3_spend less")(8/9=9 "9_dk or refusal"), gen(soclopayN)
recode socspnd4 (1 2=1 "1_spend more")(3=2 "2_spend same")(4/5=3 "3_spend less")(8/9=9 "9_dk or refusal"), gen(socsparN)
recode socspnd5 (1 2=1 "1_spend more")(3=2 "2_spend same")(4/5=3 "3_spend less")(8/9=9 "9_dk or refusal"), gen(socretN)
recode socspnd6 (1 2=1 "1_spend more")(3=2 "2_spend same")(4/5=3 "3_spend less")(8/9=9 "9_dk or refusal"), gen(soccarN)
mvdecode socspnd?, mv(8=.d \ 9=.r)

* Other related vars on spending more/less
recode taxspend (-7 -2=.n)(4 5 8 9=9 "9_None or dk or refusal")(1=1 "1_Reduce taxes and spend less on health, education etc")(2=2 "2_Keep taxes and spending on these services at same level")(3=3 "3_Increase taxes and spend more on health, education etc"), gen(taxspendN)		// For BSA-compatible output
mvdecode taxspend, mv(-7 -2=.n \ 4/8=.d \ 9=.r)
recode morewelf (-2 -1 0=.n)(1/2=1 "1_agree(strongly)")(3=2 "2_neither")(4/5=3 "3_disagree(strongly)")(8/9=9 "9_dk or refusal"), gen(morewelfN)
mvdecode morewelf, mv(-7=.t \ -2 =.s \ -1=.s \ 8=.d \ 9=.r) 	// As above for the `benattvars'
*recode taxspend (-7 -2=.)(9=.r)(1=1 "1_Reduce taxes and spend less on health, education etc")(2=2 "2_Keep taxes and spending on these services at same level")(3=3 "3_Increase taxes and spend more on health, education etc")(4 5 8=4 "4_None or dk"), gen(taxspendR)		// See OneNote for explanation - this is for sensitivity analysis
recode dole (1=1 "1_too low and cause hardship")(2=3 "3_too high and discourge work")(3/7=2 "2_other response")(else=.), gen(doleT)
recode dole (1=1 "1_too low and cause hardship")(2=3 "3_too high and discourge work")(3/9=2 "2_other response inc refusal DK")(-7 -2=.), gen(doleN)
* doleB no longer generated
*/

	
			
////////////////////////////////////////////////////
// Income and finances
////////////////////////////////////////////////////

* Actual income levels - trying to turn these into consistent quartiles and deciles
capture label drop hhincome			// They refer to different values each year - see the Excel file embedded in OneNote for details
recode hhincome (97 99=.r)(98=.d)
recode hhincd (97 99=.r)(98=.d)
recode hhincq (7 9=.r)(8=.d)
svyset [pweight=wtfactor]
global subsamp "((rsex==1 & rage<65)|(rsex==2 & rage<60)) & mainbenB~=1"

/* To export to a separate file the cumulative percentages, which I then use in the following section
forvalues year = 1988/2013	{
	dis in red "Year is `year'"
	capture svy: tab hhincome if svyyear==`year'
	if _rc==0	eststo cuminc`year': svy: tab hhincome if svyyear==`year'
	/**/					}
esttab cuminc* using "${dodir}\Outputs\0_cumincome", csv not nostar nonum nodepvars replace b(%4.3f)
forvalues year = 2010/2013	{
	dis in red "Year is `year'"
	capture svy: tab hhincd if svyyear==`year'
	if _rc==0	eststo cuminc4`year': svy: tab hhincd if svyyear==`year'
	if _rc==0	eststo cumincQ`year': svy: tab hhincq if svyyear==`year'
	/**/					}
esttab cuminc4* cumincQ* using "${dodir}\Outputs\0_cumincome4", csv not nostar nonum nodepvars replace b(%4.3f)
* DOING THIS FOR THE WORKING AGE NON-BEN-CLAIMING SUBSAMPLE
estimates clear
forvalues year = 1995/2013	{
	dis in red "Year is `year'"
	capture svy: tab hhincome if svyyear==`year' & ${subsamp}
	if _rc==0	eststo cuminc_`year': svy: tab hhincome if svyyear==`year'
	/**/					}
forvalues year = 2010/2013	{
	dis in red "Year is `year'"
	capture svy: tab hhincd if svyyear==`year'
	if _rc==0	eststo cuminc10`year': svy: tab hhincd if svyyear==`year' & ${subsamp}
	if _rc==0	eststo cuminc4`year' : svy: tab hhincq if svyyear==`year' & ${subsamp}
	/**/					}
esttab cuminc_* cuminc10* cuminc4* using "${dodir}\Outputs\0_cumincome_squz", csv not nostar nonum nodepvars replace b(%4.3f)
*/
// The recoding to income quartiles (v1 for whole pop)
recode hhincome (1/3=1)(4/6=2) (7/9=3)  (10/11=4) if svyyear==1983 | svyyear==1984	, gen(inc1983)
recode hhincome (1/3=1)(4/7=2) (8/9=3)  (10/11=4) if svyyear==1985					, gen(inc1985)
recode hhincome (1/4=1)(5/8=2) (9/10=3) (11/13=4) if svyyear==1986 | svyyear==1987	, gen(inc1986)
recode hhincome (1/5=1)(6/9=2) (10/12=3)(13/14=4) if svyyear==1989					, gen(inc1989)
recode hhincome (2/6=1)(7/10=3)(11/13=3)(14/17=4) if svyyear==1990					, gen(inc1990)
recode hhincome (3/5=1)(7/9=2) (10/13=3)(14/18=4) if svyyear==1991					, gen(inc1991)
recode hhincome (3/7=1)(8/10=2)(11/14=3)(15/20=4) if svyyear==1994 | svyyear==1995	, gen(inc1994)
recode hhincome (3/7=1)(8/11=2)(12/15=3)(16/20=4) if svyyear==1996					, gen(inc1996)
recode hhincome (3/7=1)(8/10=2)(11/14=3)(15/20=4) if svyyear==1997					, gen(inc1997)
recode hhincome (3/7=1)(8/11=2)(12/15=3)(16/21=4) if svyyear==1998					, gen(inc1998)
recode hhincome (3/8=1)(9/12=2)(13/16=3)(17/22=4) if svyyear==1999					, gen(inc1999)
recode hhincome (3/8=1)(9/12=2)(13/17=3)(18/24=4) if svyyear==2000 | svyyear==2001	, gen(inc2000)
recode hhincome (1/5=1)(6/9=2) (10/13=3)(14/17=4) if svyyear>=2002 & svyyear<=2004	, gen(inc2002)
recode hhincome (1/5=1)(6/10=2)(11/14=3)(15/17=4) if svyyear>=2005 & svyyear<=2008	, gen(inc2005)
recode hhincome (1/6=1)(7/11=2)(12/15=3)(16/17=4) if svyyear==2009					, gen(inc2009)
gen incquartiles = .
forvalues i = 1983/2009	{
	capture replace incquartiles = inc`i' if missing(incquartiles) & inc`i'~=.
	capture drop inc`i'
	/**/				}
forvalues i = 2010/2013 {
	replace incquartiles = hhincq if svyyear==`i' & missing(incquartiles) & hhincq~=.
	/**/				}
* Tidying both versions
label define incquartiles 1 "1_low income" 2 "2_mid-low income" 3 "3_mid-high income" 4 "4_high income", modify
label values incquartiles incquartiles
eststo incquartiles: svy: tab svyyear incquartiles, row
esttab incquartiles using "${logdir}\0_incquartiles", csv not nostar nonum nodepvars replace b(%4.3f)	// Changed file location from original version
estimates drop incquartiles



////////////////////////////////////////////////////
// Misc
////////////////////////////////////////////////////
		
* Dates and times - main int in 2007 done 15/Jun to 24/Nov 2007; self-comp done 9/Jun to 24 Nov 2007, but both primarily Jul-Sep => Aug used for claim rates (as closest)
gen syear = year(sintdateNUM)
	gen smonth = month(sintdateNUM)
	gen sday = day(sintdateNUM)
	sum syear smonth sday
tostring qdate, gen(qdateS) format(%04.0f) 
	replace qdateS = "" if qdate==9999 | qdate==-1	
	gen qmonth = substr(qdateS, 3, 2)
	destring qmonth, replace
	gen qday = substr(qdateS, 1, 2)
	destring qday, replace
	
* Final bits of usual BSA working file
gen uniqueid = _n // Generating a unique ID for saving and restoring estimates, 16/5/2014
order uniqueid, before(serial)


////////////////////////////////////////////////////
// For this particular analysis
////////////////////////////////////////////////////

* Renaming so that constant names across datasets
rename rage 		_age
rename wtfactor		_weight
rename libauth		_libauth
rename wkjbhrsi 	_wrkhours
rename uniqueid		_uniqueid
rename svyyear		_svyyear
rename edgrp		_quals
gen _male = (rsex==1) if ~missing(rsex)
drop rsex
label define _region 14 "14_Northern Ireland", modify
recode reconpos (1 3 5=1 "1_Working f/t or unknown")(2 4=2 "2_Working p/t")(10=3 "3_F/t student")(9=4 "4_Retired") ////
	(6 7=5 "5_Unemployed or waiting to start")(8 11=6 "6_Other non-work")(99=.r)(-9 -2=.n), gen(_work1)
	label var _work1 "Work status, small jobs=non work (except EFCYouGov)"
clonevar _work2 = _work1
	label var _work2 "Work status, small jobs=p/t work (except EFCYouGov, BSA)"
rename reconact		_ecactivity
rename mainbenB		_mainbenB			// Other benefit vars are derived above with correct names for this project
rename rclassgp		_rclassgp
rename incquartiles _incquartiles
recode leftrigh (-1=.x)(9=.r), gen(_lrscale2)
	replace _lrscale2 = (_lrscale2 -1)/4*10
	label var _lrscale2 "Left-right scale based on answer to multiple questions (not self-reported)"
// _partyid is generated above with the correct names for this project

* Selecting vars
save "${workingdir}\\${filename}_bsa", replace		// Saved above at an earlier stage too
keep D* _* ub1* ubc* mum* car_* caron* carpoor* pen1* penc* falseJSA falseIB ///
	spenmost spennext spenlast socbmost socbnext socblast morewelf *100 
drop *N*			//  This is one version of the ub1* variables, with missing variable coding for BSA report outputs - not needed here

* Finishing
compress
aorder
order *100, last
save "${workingdir}\\${filename}_bsa", replace		// Saved above at an earlier stage too
/*
	use "${workingdir}\\${filename}_bsa", replace
*/
	
