////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////
// Adapted from ESS file for Stigma 2012 report in 2015/3/27
////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////

clear
use "${ESSdir}\ESS4e04_3.dta"
numlabel, add mask(#_)
keep if essround==4 & ~missing(cntry)			// Added Dec 2015, this seems to be non-responses of some form


****************************************************
** BELIEF VARIABLES
****************************************************

mvdecode uemplwk sickdsb brnocnt, mv(77 99=.r\88=.d)
foreach var in uemplwk sickdsb brnocnt	{
	recode `var' (1=2) (2=7) (3=12) (4=17) (5=22) (6=27) (7=32) (8=37) (9=42) (10=47) (11=50), gen(`var'N)
	/**/								}
// Not looking at the poverty question, because this is hard to classify as 'factual knowledge' as opposed to definitional differences

rename brnocnt oth_bornabroad


****************************************************
** DESERVINGNESS VARIABLES
****************************************************

label define agree5 1 "1_Agree strongly" 2 "2_Agree" 3 "3_Neither agree nor disagree" 4 "4_Disagree" 5 "5_Disagree strongly", replace
foreach var in uentrjb lbenent bennent prtsick {
	ren `var' D`var'
	recode D`var' (0 7 9=.r)(8=.d)
	label values D`var' agree5
/**/ }


****************************************************
** OTHER CLEANING
****************************************************
rename idno			_uniqueid
encode cntry, gen(_country)
	numlabel _country, mask(#_) add
recode agea (999=.), gen(_age)
recode gndr (1=1)(2=0)(9=.r), gen(_male)
rename pspwght		_weight			// _dweight is the design weight only; this adjusts according to the European LFS - no need for PWEIGHT (Population size weights)
rename edulvla		_qualsintl
mvdecode _qualsintl, mv(0 55=.o\77 99=.r\88=.d)
recode _qualsintl (5 4=4)
label define iscedR 1 "1_Less than lower secondary education (ISCED 0-1)" 	///
					2 "2_Lower secondary education completed (ISCED 2)" 	///
					3 "3_Upper secondary education completed (ISCED 3)"		///
					4 "4_Tertiary or post-secondary non-tertiary education completed (ISCED 4-6)"
label values _qualsintl iscedR

// Recoding variables to be consistent across datasets
recode regiongb (8=13)(9=10)(10=11)(11=12)(12=14), gen(_region)
recode edlvgb (4 5=1)(2 3=2)(1=3)(0=4)(77 99=.r)(88=.d), gen(_quals)
recode mnactic (1=1)(2=3)(6=4)(3 4=5)(5 7 8 9=6)(77 99=.r)(88=.d), gen(_work2)
	replace _work2 = 2 if wkhtot<30
clonevar _work1 = _work2
	replace _work1 = 6 if wkhtot<8
recode hincsrca (5 6=1)(1/4 7 8=0)(77 99=.r)(88=.d), gen(_mainbenB)
recode hinctnta (1 2=1)(3/5=2)(6/8=3)(9/10=4)(77 99=.r)(88=.d) if cntry=="GB", gen(_incquartiles)
recode prtclgb (1=1)(2=2)(3=3)(4/15=5)(66 77 88=6), gen(_partyid)
recode prtvtgb (1=1)(2=2)(3=3)(4/15=5)(66 77 88=6) if vote~=3, gen(_partyvoted)		// vote==3 are people who are not eligible to vote
recode lrscale (77 99=.r)(88=.d), gen(_lrscale)
	
// Ending
keep uemplwk* sickdsb* oth* D* _*
compress
aorder
save "${workingdir}\\${filename}_ESS08", replace
/*
use "${workingdir}\\${filename}_ESS08", replace
*/
