////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////
// NEW DATA CLEANING - dataset not used previously
////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////

// Import the dataset they sent over
*usespss "${MORI2015dir}\Perils of finance SPSS wtd.sav"		// Works, but better to go into SPSS and saved it in Stata
use "${MORI2015dir}\Perils of finance SPSS wtd.dta", replace	
numlabel _all, add mask(#_)
save, replace


****************************************************
** CLEANING BENEFIT BELIEFS VARIABLES
****************************************************

// Renaming the relevant variables
rename ST08		outofwrk2014
rename ST09		outofwrk2000
gen outofwrk_trend = outofwrk2014 - outofwrk2000	
	label var outofwrk_trend "Implied trend in out-of-work ben claims 2000-2014"


****************************************************
** CLEANING OTHER BELIEFS VARIABLES
****************************************************

rename	ST02A		oth_maths1
rename	ST02B		oth_maths2
rename 	STO3		oth_milk
rename 	STO5		oth_nursery		
rename 	ST06		oth_stdntdebt
rename 	ST07		oth_ftsalary
rename 	ST10		oth_house
rename 	ST11		oth_deposit
rename 	ST12		oth_rent
rename 	ST13		oth_rentLDN
rename 	ST14		oth_debt
rename 	ST15		oth_toprate
rename 	ST16a		oth_taxtoprate1
rename 	ST16b		oth_taxtoprate2
rename 	ST17		oth_LE65
rename 	ST19		oth_annuity
rename 	ST20_1_scale	oth_coalitiondebt
rename 	ST20_2_scale	oth_coalitiondeficit
rename 	ST21		oth_baserate
rename 	ST22_new	oth_avgbaserate



****************************************************
** OTHER VARS / FINAL THINGS
****************************************************

// Renaming variables for consistency across surveys
rename Respondent_Serial	_uniqueid
rename weight				_weight
rename resp_age				_age
recode resp_gender (1=1)(2=0), gen(_male)
rename QSG 					_sgrade

// Making categorial vars have similar groupings
recode QREGION (1=1)(2=2)(3=3)(4=5)(5=4)(6=7)(7=6)(8=10)(9=13)(10=11)(11=12)(12=14), gen(_region) 	// To match BSA categories (see OneNote)
gen _quals = . if missing(QEDU)			
	replace _quals=1 if QEDU==6 | QEDU==7
	replace _quals=2 if QEDU==5 
	replace _quals=3 if QEDU==4 | QEDU==3
	replace _quals=4 if QEDU==1 | QEDU==2
recode QINC (1/4=1 "1_lowest income quartile")(5/6=2)(7=3)(8/10=4)(11=.r), gen(_incquartiles)
recode QEMP (1 3=1)(2=2)(8=3)(7=4)(4=5)(5 6=6), gen(_work1)
clonevar _work2 = _work1

// Political vars
recode QPVI1 (1=1)(2=2)(3=3)(4 5 6=5)(7 8 9=6), gen(_partyvote)
	replace _partyvote = 1 if QPVI2==1
	replace _partyvote = 2 if QPVI2==2
	replace _partyvote = 3 if QPVI2==3
	replace _partyvote = 4 if QPV1B==2	| QPV1B_o1=="ukip"		
	replace _partyvote = 5 if QPV1B==1 | QPV1B==3 | QPV1B==5 | QPV1B_o1=="SNP" | QPV1B_o1=="independent" |	///
		QPVI2==6 | QPVI2==9 	// other parties
	replace _partyvote = 6 if QPV1B==6 | QPVI2==10 | QPVI2==11 | QPVI2==12									// undecided = DK
recode QPVI4 (1=1)(2=2)(3=3)(5=4)(4 6 7 8 13=5)(9 11 12=6)(10=.n), gen(_partyvoted)
clonevar _partywldvote = QPVI3 
	replace _partywldvote = .d if QPVI3==11

// Ending
keep outofwrk* oth* _*
compress
aorder
order outofwrk*, after(_weight)
order oth*, last
save "${workingdir}\\${filename}_MORI2015", replace
/*
	use "${workingdir}\\${filename}_RSSMORI2013", replace
*/
