*---------------------------------------------------------------------------------------------------------------------------------------------------
* COMPARATIVE ANALYSIS OF ESS
* Note: in most UK analyses, it's the first line of the analysis file that drops the non-UK countries (e..g above, or in 3_analysis_part1.do)
* Correct figures are merged in within 1_a_master_cleaning.do line #105, into TsickdsbN (renamed sick2008) and TuemplwkN (renamed unemp2008)
*---------------------------------------------------------------------------------------------------------------------------------------------------

estimates clear
use "${workingdir}\\${filename}_combined_ForLeuvenCh", replace	
keep if _data=="ESS08" & ~missing(TuemplwkN)
do "${dodir}\\4_correct_values_ESSintl.do"

// GROUPING DESERVINGNESS VARIABLE CATEGORIES
foreach var in Dbennent Duentrjb  {
	recode `var' (1/2=1 "1_Agree")(3=2   "2_Neither")(4/5=3 "3_Disagree"), gen(`var'T)
	recode `var' (1/2=1 "1_Agree")(3/5=0 "0_Neither/Disagree"), gen(`var'B)
/**/ }

// CORRECTNESS OF sickdsbN and uemplwkN in EACH country
label define correctness 1 "1_Correct" 2 "2_Underestimate" 3 "3_Overestimate" 4 "4_DontKnow", modify
label define correctcat  0 "0_Incorrect" 1 "1_Correct" 9 "9_DontKnow", modify
* This is so that each category is filled, so that the proportions work even if e.g. there are no underestimates
local new = _N + 1
set obs `new'
* The main loop
foreach depvar in sickdsbN uemplwkN {
	capture drop `depvar'T
	gen `depvar'T=.
	levelsof(_nation)
	foreach country in `r(levels)' {
		quietly sum T`depvar' if _nation==`country'
		if r(N)>0 {
			dis "Country is `country', depvar is `depvar', target var is correct_`depvar'L_`country'"
			dis "Low is " ${correct_`depvar'L_`country'} " and high is " ${correct_`depvar'H_`country'}
			replace		`depvar'T = 1 if _nation==`country' & `depvar'>=${correct_`depvar'L_`country'} & `depvar'<=${correct_`depvar'H_`country'}
			replace  	`depvar'T = 2 if _nation==`country' & `depvar'< ${correct_`depvar'L_`country'} 
			replace		`depvar'T = 3 if _nation==`country' & `depvar'> ${correct_`depvar'H_`country'} & ~missing(`depvar')
			replace		`depvar'T = 4 if _nation==`country' & `depvar'==.d	
		/**/ }	
	/**/ }	
	replace `depvar'T = 2 in `new'
	label values `depvar'T correctness
	label var `depvar'T "Correctness of `var'"
	* And an unlabelled version
	capture drop `depvar'Tnol
	gen `depvar'Tnol = `depvar'T
/**/ }

	
	
**************************************************************
* Generating descriptive results for continuous variables
**************************************************************/

foreach var in sickdsbN TsickdsbN uemplwkN TuemplwkN  {
	eststo mean_`var': 	mean `var' [pw=_weight], over(_nation, nolab)
/**/ }
esttab mean*, not nostar b(%3.2f) depvars

eststo prop_sickdsbNTnol : 	proportion sickdsbNTnol [pw=_weight], over(_nation, nolab) nolab
eststo prop_uemplwkNTnol : 	proportion uemplwkNTnol [pw=_weight], over(_nation, nolab) nolab
esttab prop*, nostar not unstack

// DESCRIPTIVE STATISTICS FOR CONTROLS
foreach var in _male _qualsintl _work1 _mainbenB {
	eststo descs_cat_`var': prop `var' [pw=_weight], over(_nation, nolab)
/**/ }
esttab descs_cat* using "${dodir}\Outputs\control_descs2.csv", replace csv nostar not noparentheses nonum unstack
eststo descs_cont: mean _age _lrscale [pw=_weight], over(_nation, nolab)
table _nation 					, c(count _lrscale count _male count _qualsint)
table _nation					, c(count _age max _age min _age)



**************************************************************
* Generating regression results for continuous variables
**************************************************************/

* The program for continuous data
capture program drop cont_dependency_country
program define cont_dependency_country, eclass

	syntax [anything]
	tokenize "`anything'"
	local beliefvar		"`1'"
	local dependency	"`2'"
	local country		"`3'"
	dis "beliefvar is `beliefvar', dependency is `dependency', country is `country'"

	* Regression of dependency on belief (various versions):
	sum `beliefvar' if `beliefvar'Tnol==1 & _nation==`country'
	if r(N)>0 {
			local max_`beliefvar' = r(max)			// This sets the counterfactual for use in the margins command in what follows
		// The list of regressions
		local reg1 "  `beliefvar'"
		local reg2 "  `beliefvar'   c._lrscale c._age c._age#c._age i._qualsintl  _male i._work1 i._mainbenB"
		local reg3 "c.`beliefvar'##(c._lrscale c._age c._age#c._age i._qualsintl) _male i._work1 i._mainbenB"
		// The models, looped
		forvalues j = 1/3 {
			eststo R`j'_`beliefvar'_`dependency'_`country': 	logit `dependency'B `reg`j'' if _nation==`country' [pw=_weight]
				* Interactions with beliefs for `beliefvar' and `dependency', for control variables #`j'
				if `j' == 3{
					testparm c._lrscale#c.`beliefvar' 
						estadd scalar int_lrscale = r(p)
					testparm c.`beliefvar'#c._age c.`beliefvar'#c._age#c._age 
						estadd scalar int_age = r(p)
					testparm _qualsintl#c.`beliefvar'
						estadd scalar int_qualsintl = r(p)
					testparm c._lrscale#c.`beliefvar' 	c.`beliefvar'#c._age 	c.`beliefvar'#c._age#c._age 	_qualsintl#c.`beliefvar' 	
						estadd scalar int_demogs= r(p)											: R`j'_`beliefvar'_`dependency'_`country'
					capture eststo MR`j'_`beliefvar'_`dependency'`country': margins, dydx(c.`beliefvar') at(_age=(20 40 60)) at(_qualsintl=(1(1)4)) at(_lrscale=(0 5 10)) post vsquish
				/**/ }
			* Average marginal effect
			estimates restore R`j'_`beliefvar'_`dependency'_`country'
			margins, dydx(`beliefvar') post
				matrix output = e(b)
				estadd scalar belief_effect = output[1,1]										: R`j'_`beliefvar'_`dependency'_`country'
			* Simulation
			estadd scalar counterfactual_belief =  `max_`beliefvar''							: R`j'_`beliefvar'_`dependency'_`country'	// Noting the counterfactual for the simulation
			estimates restore R`j'_`beliefvar'_`dependency'_`country'
			margins, at(`beliefvar'=`max_`beliefvar'') at((asobs) `beliefvar') post
				matrix output = e(b)
					estadd scalar iftrue = output[1,1]											: R`j'_`beliefvar'_`dependency'_`country'
					estadd scalar actual = output[1,2]											: R`j'_`beliefvar'_`dependency'_`country'
				test _b[1._at] = _b[2._at]
					estadd scalar sig_counterfactual = r(p)										: R`j'_`beliefvar'_`dependency'_`country'
				lincom _b[1._at] - _b[2._at]
					estadd scalar ci_lb = r(estimate) + invnorm(0.025)*r(se)					: R`j'_`beliefvar'_`dependency'_`country'
					estadd scalar ci_ub = r(estimate) + invnorm(0.975)*r(se)					: R`j'_`beliefvar'_`dependency'_`country'
		/**/ }	
	/**/ }	
	// NOTE: have removed dummy vars for refusals and don't knows, as don't think these are used
end

* Running this for each pair of variables
local pair1  "sickdsbN 		Dbennent"
local pair2  "uemplwkN 		Dbennent"
local pair3  "sickdsbN 		Duentrjb "
local pair4  "uemplwkN 		Duentrjb "
// The loop
forvalues i = 1/4 {
	// Running separately for each country
	levelsof(_nation)
	foreach country in `r(levels)' {
		dis "Pair `i' is `pair`i'', country is `country'"
		cont_dependency_country `pair`i'' `country'
	/**/ }
	// Interacting nation with everything
	local dependency	= word("`pair`i''", 2) 
	local beliefvar 	= word("`pair`i''", 1) 
	eststo Int1_`beliefvar'_`dependency': 	logit `dependency'B c.`beliefvar'##_nation [pw=_weight]
		testparm i._nation#c.`beliefvar'
		estadd scalar sig_interaction = r(p)											: Int1_`beliefvar'_`dependency'
	eststo Int2_`beliefvar'_`dependency': 	logit `dependency'B c.`beliefvar'##_nation _lrscale _male c._age c._age#c._age i._qualsintl i._work1 i._mainbenB [pw=_weight]
		testparm i._nation#c.`beliefvar'
		estadd scalar sig_interaction = r(p)											: Int2_`beliefvar'_`dependency'
	// Looking at whether different impacts in different countries through random slope models	
	// To use weights, need to use the MIXED (prev XTMIXED) command and treat as continuous outcome
	eststo SL1_`beliefvar'_`dependency':	xtmelogit `dependency'B c.`beliefvar' 	_lrscale _male c._age c._age#c._age i._qualsintl i._work1 i._mainbenB || _nation: c.`beliefvar' // NOTE xtmelogit is the old name for what is now MEQRLOGIT
	eststo SL2_`beliefvar'_`dependency':	mixed `dependency' c.`beliefvar'		_lrscale _male c._age c._age#c._age i._qualsintl i._work1 i._mainbenB [pw=_weight] || _nation: c.`beliefvar', pwscale(size)
	eststo SL3_`beliefvar'_`dependency':	mixed `dependency' c.`beliefvar'		_lrscale _male c._age c._age#c._age i._qualsintl i._work1 i._mainbenB [pw=_weight] || _nation: c.`beliefvar', pwscale(size) covariance(unstructured)		
	* Need to save these in two chunks, otherwise you exceed the Stata system limit for stored estimates
	if `i' == 2 | `i'==4 {
		esttab R1* R2*		using "${dodir}\Outputs\Leuven_regsintl`i'.csv"	, replace csv compress nostar p(%4.3f) noparentheses nodepvars nonum varwidth(15) ///
			modelwidth(25) scalars(belief_effect counterfactual_belief iftrue actual sig_counterfactual ci_lb ci_ub int_lrscale int_age int_qualsintl int_demogs) sfmt(%5.4f)
		esttab R3* 			using "${dodir}\Outputs\Leuven_regsintl`i'_int.csv", replace csv compress nostar p(%4.3f) noparentheses nodepvars nonum varwidth(15) ///
			modelwidth(25) scalars(belief_effect counterfactual_belief iftrue actual sig_counterfactual ci_lb ci_ub int_lrscale int_age int_qualsintl int_demogs) sfmt(%5.4f)
		estimates drop R*	
	/**/ }
/**/ }


* Outputting
esttab Int*		using "${dodir}\Outputs\Leuven_regsintl_interactions.csv", replace csv compress nostar p(%4.3f) noparentheses nodepvars nonum ///
	varwidth(15) modelwidth(25) scalars(sig_interaction) sfmt(%5.4f)
esttab SL*		using "${dodir}\Outputs\Leuven_regsintl_randomslope.csv",  replace csv compress nostar p(%4.3f) noparentheses nodepvars nonum ///
	varwidth(15) modelwidth(25) 
